typst_
analyzer_
analysis
0.1.10
All Items
Crate Items
Modules
Macros
Functions
Crate
typst_analyzer_analysis
Modules

completion
definition
dict
node
Macros

typ_
logger
A macro for logging messages to a file in the Typst Analyzer cache directory.
Functions

calculate_
inlay_
hints
check_
unclosed_
delimiters
find_
project_
root
Finds the project root by searching upward for a marker file/directory (e.g.,
.git
)
get_
images