typst_
analyzer_
analysis
0.1.10
Module node
Module Items
Functions
In crate typst_
analyzer_
analysis
typst_analyzer_analysis
Module
node
Functions

node_
walker
Walks down the AST from current cursor position and Returns a vector of SyntaxKind. Must provide markup in vector in all cases since thas is the root.