node_walker

Function node_walker 

pub fn node_walker(pos: usize, ast: &SyntaxNode) -> Vec<SyntaxKind>
Walks down the AST from current cursor position and Returns a vector of SyntaxKind. Must provide markup in vector in all cases since thas is the root.